@@ -444,6 +444,9 @@ impl AquaFile {
 }
 
 fn apply_override(mut orig: AquaPackage, avo: &AquaPackage) -> AquaPackage {
+    if avo.r#type != AquaPackageType::GithubRelease {
+        orig.r#type = avo.r#type.clone();
+    }
     if !avo.repo_owner.is_empty() {
         orig.repo_owner = avo.repo_owner.clone();
     }
