@@ -49,14 +49,7 @@ impl Backend for AquaBackend {
     fn _list_remote_versions(&self) -> Result<Vec<String>> {
         let pkg = AQUA_REGISTRY.package(&self.id)?;
         if !pkg.repo_owner.is_empty() && !pkg.repo_name.is_empty() {
-            let versions = if let Some("github_tag") = pkg.version_source.as_deref() {
-                github::list_tags(&format!("{}/{}", pkg.repo_owner, pkg.repo_name))?
-            } else {
-                github::list_releases(&format!("{}/{}", pkg.repo_owner, pkg.repo_name))?
-                    .into_iter()
-                    .map(|r| r.tag_name)
-                    .collect_vec()
-            };
+            let versions = get_versions(&pkg)?;
             Ok(versions
                 .into_iter()
                 .filter_map(|v| {
@@ -581,6 +574,21 @@ impl AquaBackend {
     }
 }
 
+fn get_versions(pkg: &AquaPackage) -> Result<Vec<String>> {
+    if let Some("github_tag") = pkg.version_source.as_deref() {
+        let versions = github::list_tags(&format!("{}/{}", pkg.repo_owner, pkg.repo_name))?;
+        return Ok(versions);
+    }
+    let mut versions = github::list_releases(&format!("{}/{}", pkg.repo_owner, pkg.repo_name))?
+        .into_iter()
+        .map(|r| r.tag_name)
+        .collect_vec();
+    if versions.is_empty() {
+        versions = github::list_tags(&format!("{}/{}", pkg.repo_owner, pkg.repo_name))?;
+    }
+    Ok(versions)
+}
+
 fn validate(pkg: &AquaPackage) -> Result<()> {
     let envs: HashSet<&str> = pkg.supported_envs.iter().map(|s| s.as_str()).collect();
     let os = os();
