@@ -70,16 +70,20 @@ impl MultiProgressReport {
             None => f(),
         }
     }
+    pub fn stop(&self) -> eyre::Result<()> {
+        if let Some(mp) = &self.mp {
+            mp.clear()?;
+        }
+        Ok(())
+    }
 }
 
 #[cfg(test)]
 mod tests {
     use super::*;
-    use crate::test::reset;
 
     #[test]
     fn test_multi_progress_report() {
-        reset();
         let mpr = MultiProgressReport::get();
         let pr = mpr.add("PREFIX");
         pr.finish_with_message("test".into());
